@@ -19,4 +19,12 @@ module.exports = {
   moduleDirectories: [
     'node_modules',
   ],
+  coverageThreshold: {
+    global: {
+      statements: 78,
+      branches: 75,
+      functions: 75,
+      lines: 78,
+    },
+  },
 };
