@@ -16,10 +16,13 @@ import { DevWorkspaceTemplateApiService } from './services/devWorkspaceTemplateA
 import { DockerConfigApiService } from './services/dockerConfigApi';
 import { EventApiService } from './services/eventApi';
 import { KubeConfigApiService } from './services/kubeConfigApi';
+import { PodmanApiService } from './services/podmanApi';
+import { LogsApiService } from './services/logsApi';
 import { NamespaceApiService } from './services/namespaceApi';
-import { PodApiService } from './services/podAPI';
+import { PodApiService } from './services/podApi';
 import { ServerConfigApiService } from './services/serverConfigApi';
 import { UserProfileApiService } from './services/userProfileApi';
+import { IPodmanApi } from './types/index';
 import {
   IDevWorkspaceApi,
   IDevWorkspaceClient,
@@ -27,6 +30,7 @@ import {
   IDockerConfigApi,
   IEventApi,
   IKubeConfigApi,
+  ILogsApi,
   INamespaceApi,
   IPodApi,
   IServerConfigApi,
@@ -70,6 +74,10 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
     return new KubeConfigApiService(this.kubeConfig);
   }
 
+  get podmanApi(): IPodmanApi {
+    return new PodmanApiService(this.kubeConfig);
+  }
+
   get namespaceApi(): INamespaceApi {
     return new NamespaceApiService(this.kubeConfig);
   }
@@ -77,4 +85,8 @@ export class DevWorkspaceClient implements IDevWorkspaceClient {
   get userProfileApi(): IUserProfileApi {
     return new UserProfileApiService(this.kubeConfig);
   }
+
+  get logsApi(): ILogsApi {
+    return new LogsApiService(this.kubeConfig);
+  }
 }
