@@ -14,7 +14,7 @@ import { FastifyInstance, FastifyRequest } from 'fastify';
 import { baseApiPath } from '../../constants/config';
 import { namespacedSchema } from '../../constants/schemas';
 import { getSchema } from '../../services/helpers';
-import { restParams } from '../../typings/models';
+import { restParams } from '../../models';
 import { getDevWorkspaceClient } from './helpers/getDevWorkspaceClient';
 import { getToken } from './helpers/getToken';
 
