@@ -16,7 +16,7 @@ import { baseApiPath } from '../../constants/config';
 import { yamlResolverSchema, namespacedSchema } from '../../constants/schemas';
 import { getDevWorkspaceClient } from './helpers/getDevWorkspaceClient';
 import { getToken } from './helpers/getToken';
-import { restParams } from '../../typings/models';
+import { restParams } from '../../models';
 import { getSchema } from '../../services/helpers';
 import { helpers } from '@eclipse-che/common';
 
