@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -97,7 +97,10 @@ describe('About Menu', () => {
     const documentationItem = screen.getByRole('menuitem', { name: /Documentation/i });
     fireEvent.click(documentationItem);
 
-    expect(global.open).toHaveBeenCalledWith('https://www.eclipse.org/che/docs/che-7', '_blank');
+    expect(global.open).toHaveBeenCalledWith(
+      'https://www.eclipse.org/che/docs/stable/overview/introduction-to-eclipse-che/',
+      '_blank',
+    );
   });
 
   it('should open page with the community url', () => {
