@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -12,28 +12,29 @@
 
 import React from 'react';
 import { WizardStep } from '@patternfly/react-core';
-import { CheckCircleIcon, ExclamationCircleIcon, InProgressIcon } from '@patternfly/react-icons';
+import {
+  CheckCircleIcon,
+  ExclamationCircleIcon,
+  InProgressIcon,
+  ExclamationTriangleIcon,
+} from '@patternfly/react-icons';
 
 import workspaceStatusLabelStyles from '../../WorkspaceStatusLabel/index.module.css';
 import styles from './index.module.css';
 
 export enum LoadingStep {
   INITIALIZE = 1,
+  CHECK_RUNNING_WORKSPACES_LIMIT,
   CREATE_WORKSPACE,
   CREATE_WORKSPACE__FETCH_DEVFILE,
   CREATE_WORKSPACE__FETCH_RESOURCES,
   CREATE_WORKSPACE__CHECK_EXISTING_WORKSPACES,
   CREATE_WORKSPACE__APPLY_DEVFILE,
   CREATE_WORKSPACE__APPLY_RESOURCES,
-  CHECK_RUNNING_WORKSPACES_LIMIT,
   START_WORKSPACE,
   OPEN_WORKSPACE,
 }
 
-export function isIdeStep(loadingStep: LoadingStep): boolean {
-  return loadingStep === LoadingStep.START_WORKSPACE || loadingStep === LoadingStep.OPEN_WORKSPACE;
-}
-
 function getStepTitle(id: LoadingStep): string {
   switch (id) {
     case LoadingStep.INITIALIZE:
@@ -63,7 +64,8 @@ export class LoaderStep {
   private _id: number;
   private _title: string;
   private _parentId: number | undefined;
-  public hasError: boolean;
+  public hasError = false;
+  public hasWarning = false;
 
   static toWizardSteps(
     currentStepId: number,
@@ -101,30 +103,38 @@ export class LoaderStep {
   }
 
   private buildIcon(currentStepId: number): React.ReactNode {
-    if (currentStepId < this.id) {
-      return '';
-    }
-
-    if (currentStepId > this.id) {
-      return (
-        <CheckCircleIcon data-testid="step-done-icon" className={styles.stepIcon} color="green" />
-      );
-    }
-
     if (this.hasError) {
       return (
         <ExclamationCircleIcon
           data-testid="step-failed-icon"
-          className={styles.stepIcon}
-          color="red"
+          className={`${styles.errorIcon} ${styles.stepIcon}`}
+        />
+      );
+    }
+
+    if (this.hasWarning) {
+      return (
+        <ExclamationTriangleIcon
+          data-testid="step-warning-icon"
+          className={`${styles.warningIcon} ${styles.stepIcon}`}
+        />
+      );
+    }
+
+    if (currentStepId < this.id) {
+      return '';
+    } else if (currentStepId > this.id) {
+      return (
+        <CheckCircleIcon
+          data-testid="step-done-icon"
+          className={`${styles.successIcon} ${styles.stepIcon}`}
         />
       );
     } else {
       return (
         <InProgressIcon
           data-testid="step-in-progress-icon"
-          className={`${workspaceStatusLabelStyles.rotate} ${styles.stepIcon}`}
-          color="#0e6fe0"
+          className={`${styles.inProgressIcon} ${workspaceStatusLabelStyles.rotate} ${styles.stepIcon}`}
         />
       );
     }
