@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,8 +10,8 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
 import { History } from 'history';
+import React from 'react';
 import { Cancellation, pseudoCancellable } from 'real-cancellable-promise';
 import { List, LoaderStep } from '../../components/Loader/Step';
 import { DisposableCollection } from '../../services/helpers/disposable';
@@ -23,6 +23,7 @@ export type LoaderStepProps = {
   tabParam: string | undefined;
   onNextStep: () => void;
   onRestart: (tabName?: string) => void;
+  onTabChange: (tab: string) => void;
 };
 export type LoaderStepState = {
   lastError?: unknown;
@@ -92,4 +93,8 @@ export abstract class AbstractLoaderStep<
       });
     });
   }
+
+  protected handleTabChange(tab: string): void {
+    this.props.onTabChange(tab);
+  }
 }
