@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,33 +10,34 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import { Store } from 'redux';
+import { StateMock } from '@react-mock/state';
+import { screen, waitFor, within } from '@testing-library/react';
+import userEvent from '@testing-library/user-event';
+import { createMemoryHistory } from 'history';
 import React from 'react';
 import { Provider } from 'react-redux';
-import { createMemoryHistory } from 'history';
-import userEvent from '@testing-library/user-event';
-import { screen, waitFor, within } from '@testing-library/react';
-import { StateMock } from '@react-mock/state';
-import { FakeStoreBuilder } from '../../../../../../store/__mocks__/storeBuilder';
+import { Store } from 'redux';
+import CreateWorkspace, { State } from '..';
 import { List, LoaderStep, LoadingStep } from '../../../../../../components/Loader/Step';
 import {
   buildLoaderSteps,
   getFactoryLoadingSteps,
 } from '../../../../../../components/Loader/Step/buildSteps';
 import getComponentRenderer from '../../../../../../services/__mocks__/getComponentRenderer';
-import CreateWorkspace, { State } from '..';
+import { FakeStoreBuilder } from '../../../../../../store/__mocks__/storeBuilder';
+import { buildFactoryParams } from '../../../../buildFactoryParams';
 import { MIN_STEP_DURATION_MS } from '../../../../const';
-import buildFactoryParams from '../../../buildFactoryParams';
 
-jest.mock('../../../../../../pages/Loader/Factory');
+jest.mock('../../../../../../pages/Loader');
 
 const { renderComponent } = getComponentRenderer(getComponent);
 
 const mockOnNextStep = jest.fn();
 const mockOnRestart = jest.fn();
+const mockOnTabChange = jest.fn();
 
 const stepId = LoadingStep.CREATE_WORKSPACE.toString();
-const currentStepIndex = 1;
+const currentStepIndex = 2;
 const loadingSteps = getFactoryLoadingSteps('devfile');
 const searchParams = new URLSearchParams();
 
@@ -106,6 +107,7 @@ function getComponent(
       tabParam={undefined}
       onNextStep={mockOnNextStep}
       onRestart={mockOnRestart}
+      onTabChange={mockOnTabChange}
     />
   );
   if (localState) {
