@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,29 +10,27 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
-import React from 'react';
-import { Action, Store } from 'redux';
-import { Provider } from 'react-redux';
-import { createMemoryHistory } from 'history';
-import userEvent from '@testing-library/user-event';
 import { screen } from '@testing-library/react';
-import { FakeStoreBuilder } from '../../../../store/__mocks__/storeBuilder';
+import userEvent from '@testing-library/user-event';
+import { createMemoryHistory } from 'history';
+import React from 'react';
+import { Provider } from 'react-redux';
+import { Store } from 'redux';
+import WorkspaceLoader from '..';
 import {
   buildLoaderSteps,
   getWorkspaceLoadingSteps,
 } from '../../../../components/Loader/Step/buildSteps';
-import getComponentRenderer from '../../../../services/__mocks__/getComponentRenderer';
-import { ActionCreators } from '../../../../store/Workspaces';
-import { AppThunk } from '../../../../store';
-import WorkspaceLoader from '..';
 import { Workspace } from '../../../../services/workspace-adapter';
+import getComponentRenderer from '../../../../services/__mocks__/getComponentRenderer';
+import { FakeStoreBuilder } from '../../../../store/__mocks__/storeBuilder';
 
 /* eslint-disable @typescript-eslint/no-non-null-assertion */
 
 jest.mock('../Steps/Initialize');
 jest.mock('../Steps/OpenWorkspace');
 jest.mock('../Steps/StartWorkspace');
-jest.mock('../Steps/CheckRunningWorkspacesLimit');
+jest.mock('../../CommonSteps/CheckRunningWorkspacesLimit');
 jest.mock('../../findTargetWorkspace.ts', () => {
   return {
     __esModule: true,
@@ -42,23 +40,11 @@ jest.mock('../../findTargetWorkspace.ts', () => {
   };
 });
 
-const mockDeleteWorkspaceLogs = jest.fn();
-jest.mock('../../../../store/Workspaces/index', () => {
-  return {
-    actionCreators: {
-      deleteWorkspaceLogs:
-        (...args: Parameters<ActionCreators['deleteWorkspaceLogs']>): AppThunk<Action, void> =>
-        (): void => {
-          return mockDeleteWorkspaceLogs(...args);
-        },
-    } as ActionCreators,
-  };
-});
-
 const { renderComponent } = getComponentRenderer(getComponent);
 
 const mockOnNextStep = jest.fn();
 const mockOnRestart = jest.fn();
+const mockOnTabChange = jest.fn();
 
 const namespace = 'che-user';
 const workspaceName = 'test-workspace';
@@ -104,7 +90,6 @@ describe('Workspace loader', () => {
       userEvent.click(restartButton!);
 
       expect(mockOnRestart).toHaveBeenCalled();
-      expect(mockDeleteWorkspaceLogs).toHaveBeenCalled();
     });
 
     test('next step switch', () => {
@@ -147,7 +132,6 @@ describe('Workspace loader', () => {
       userEvent.click(restartButton!);
 
       expect(mockOnRestart).toHaveBeenCalled();
-      expect(mockDeleteWorkspaceLogs).toHaveBeenCalled();
     });
 
     test('next step switch', () => {
@@ -190,7 +174,6 @@ describe('Workspace loader', () => {
       userEvent.click(restartButton!);
 
       expect(mockOnRestart).toHaveBeenCalled();
-      expect(mockDeleteWorkspaceLogs).toHaveBeenCalled();
     });
 
     test('next step switch', () => {
@@ -233,7 +216,6 @@ describe('Workspace loader', () => {
       userEvent.click(restartButton!);
 
       expect(mockOnRestart).toHaveBeenCalled();
-      expect(mockDeleteWorkspaceLogs).toHaveBeenCalled();
     });
 
     test('next step switch', () => {
@@ -265,6 +247,7 @@ function getComponent(store: Store, currentStepIndex: number): React.ReactElemen
         tabParam={undefined}
         onNextStep={mockOnNextStep}
         onRestart={mockOnRestart}
+        onTabChange={mockOnTabChange}
       />
     </Provider>
   );
