@@ -63,7 +63,7 @@ type State = {
 
 export const VISIBLE_TAGS = ['Community', 'Tech-Preview'];
 
-const EXCLUDED_TARGET_EDITOR_NAMES = ['che-idea', 'che-theia'];
+const EXCLUDED_TARGET_EDITOR_NAMES = ['dirigible', 'jupyter', 'eclipseide', 'code-server'];
 
 export class SamplesListGallery extends React.PureComponent<Props, State> {
   private static sortByName(a: TargetEditor, b: TargetEditor): number {
