@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -13,6 +13,7 @@
 import devfileApi, { isDevfileV2, isDevWorkspace } from '../devfileApi';
 import { DEVWORKSPACE_UPDATING_TIMESTAMP_ANNOTATION } from '../devfileApi/devWorkspace/metadata';
 import { DEVWORKSPACE_STORAGE_TYPE_ATTR } from '../devfileApi/devWorkspace/spec/template';
+import getWorkspaceLogs, { getWorkspaceErrors } from '../helpers/getWorkspaceLogs';
 import { DeprecatedWorkspaceStatus, DevWorkspaceStatus, WorkspaceStatus } from '../helpers/types';
 import {
   devfileToDevWorkspace,
@@ -42,6 +43,8 @@ export interface Workspace {
   readonly hasError: boolean;
   readonly isDevWorkspace: boolean;
   readonly isDeprecated: boolean;
+  readonly logs: string[];
+  readonly errorLogs: string[];
 }
 
 export class WorkspaceAdapter<T extends devfileApi.DevWorkspace> implements Workspace {
@@ -245,6 +248,14 @@ export class WorkspaceAdapter<T extends devfileApi.DevWorkspace> implements Work
   get projects(): string[] {
     return (this.workspace.spec.template.projects || []).map(project => project.name);
   }
+
+  get logs(): string[] {
+    return getWorkspaceLogs(this.workspace);
+  }
+
+  get errorLogs(): string[] {
+    return getWorkspaceErrors(this.workspace);
+  }
 }
 
 export function constructWorkspace<T extends devfileApi.DevWorkspace>(workspace: T): Workspace {
