@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -20,7 +20,6 @@ import { container } from '../../../inversify.config';
 import { CheWorkspaceClient } from '../../../services/workspace-client/cheworkspace/cheWorkspaceClient';
 import * as factoryResolverStore from '..';
 import { AxiosError } from 'axios';
-import { KubernetesNamespace } from '@eclipse-che/workspace-client/dist/rest/resources';
 import normalizeDevfileV1 from '../normalizeDevfileV1';
 import normalizeDevfileV2 from '../normalizeDevfileV2';
 import {
@@ -89,7 +88,9 @@ describe('FactoryResolver store', () => {
       >;
 
       const location = 'http://factory-link';
-      await store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location));
+      await store.dispatch(
+        factoryResolverStore.actionCreators.requestFactoryResolver(location, {}),
+      );
 
       const actions = store.getActions();
       expect(actions).toEqual(
@@ -119,7 +120,9 @@ describe('FactoryResolver store', () => {
       >;
 
       const location = 'http://factory-link';
-      await store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location));
+      await store.dispatch(
+        factoryResolverStore.actionCreators.requestFactoryResolver(location, {}),
+      );
 
       const actions = store.getActions();
       expect(actions).toEqual(
@@ -173,7 +176,7 @@ describe('FactoryResolver store', () => {
 
       const location = 'http://factory-link';
       await expect(
-        store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location)),
+        store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location, {})),
       ).rejects.toMatch('Unexpected error');
       expect(actions).toEqual(expectedActions);
 
@@ -205,7 +208,7 @@ describe('FactoryResolver store', () => {
 
       const location = 'http://factory-link';
       await expect(
-        store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location)),
+        store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location, {})),
       ).rejects.toMatch('The specified link does not contain a valid Devfile.');
       expect(actions).toEqual(expectedActions);
     });
@@ -242,7 +245,7 @@ describe('FactoryResolver store', () => {
 
       const location = 'http://factory-link';
       await expect(
-        store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location)),
+        store.dispatch(factoryResolverStore.actionCreators.requestFactoryResolver(location, {})),
       ).rejects.toEqual({
         attributes: {
           oauth_provider: 'oauth_provider',
