@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -28,7 +28,7 @@ export const selectDefaultPlugins = createSelector(
 
 export const selectOpenVSXUrl = createSelector(
   selectState,
-  state => state.config.pluginRegistry.openVSXURL,
+  state => state.config.pluginRegistry?.openVSXURL,
 );
 
 export const selectPvcStrategy = createSelector(
