@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Red Hat, Inc.
+ * Copyright (c) 2018-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -10,6 +10,7 @@
  *   Red Hat, Inc. - initial API and implementation
  */
 
+import { V1alpha2DevWorkspaceStatusConditions } from '@devfile/api';
 import devfileApi from '../../services/devfileApi';
 import getRandomString from '../../services/helpers/random';
 import { DevWorkspaceStatus } from '../../services/helpers/types';
@@ -93,6 +94,7 @@ export class DevWorkspaceBuilder {
   }
 
   withStatus(status: {
+    conditions?: Array<V1alpha2DevWorkspaceStatusConditions>;
     phase?: keyof typeof DevWorkspaceStatus;
     devworkspaceId?: string;
     mainUrl?: string;
@@ -101,6 +103,9 @@ export class DevWorkspaceBuilder {
     if (this.workspace.status === undefined) {
       this.workspace.status = this.buildStatus();
     }
+    if (status.conditions) {
+      this.workspace.status.conditions = Object.assign([], status.conditions);
+    }
     if (status.phase) {
       this.workspace.status.phase = DevWorkspaceStatus[status.phase];
     }
